==> e107_0.7.23_full.tar.gz: e107_languages/English/admin/lan_users.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_users.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 12:56:14 -0600 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("USRLAN_1", "Options Saved.");
define("USRLAN_3", "now listed an Administrator - to set permissions please go to the");
define("USRLAN_4", "Administrator page");
define("USRLAN_5", "You cannot remove admin status of main site admin");
define("USRLAN_6", "has had Administrator status removed.");
define("USRLAN_7", "You cannot ban the main site administrator");
define("USRLAN_8", "User banned.");
define("USRLAN_9", "User unbanned.");
define("USRLAN_10", "User deleted.");
define("USRLAN_11", "Delete cancelled.");
define("USRLAN_12", "You cannot delete the main site administrator.");
define("USRLAN_13", "Please confirm you wish to delete this member");
// define("USRLAN_14", "once deleted the record cannot be retrieved");
// define("USRLAN_15", "Cancel");
define("USRLAN_16", "Confirm Delete");
define("USRLAN_17", "Confirm Delete User");
// define("USRLAN_18", "User activated.");
// define("USRLAN_19", "Search");
// define("USRLAN_20", "Order by");
// define("USRLAN_21", "User ID");
// define("USRLAN_22", "User name");
// define("USRLAN_23", "Visits to site");
// define("USRLAN_24", "Admin status");
// define("USRLAN_25", "Status");
// define("USRLAN_26", "Descending");
// define("USRLAN_27", "Ascending");
// define("USRLAN_28", "Sort");

define("USRLAN_30", "Ban");
// define("USRLAN_31", "Ban -inactivated-");
define("USRLAN_32", "Activate");
define("USRLAN_33", "Unban");
define("USRLAN_34", "Remove admin status");
define("USRLAN_35", "Make admin");
define("USRLAN_36", "Set Class");

// define("USRLAN_37", "Members");
// define("USRLAN_38", "Search returned");
// define("USRLAN_39", "result(s)");
// define("USRLAN_40", "None defined");

define("USRLAN_44", "Allow members to upload an avatar?");

define("USRLAN_47", "Maximum avatar width (in pixels)");
define("USRLAN_48", "default is 120");
define("USRLAN_49", "Maximum avatar height (in pixels)");
define("USRLAN_50", "default is 100");
define("USRLAN_51", "Update Options");
define("USRLAN_52", "Member Options");
define("USRLAN_53", "Allow members to upload a photograph?");
define("USRLAN_54", "Click here to delete all inactivated users");
define("USRLAN_55", "Prune");
define("USRLAN_56", "Deleted");
define("USRLAN_57", "Deleting un-activated members ...");
define("USRLAN_58", "file uploads are disabled in php.ini");
define("USRLAN_59", "Quick add user");
define("USRLAN_60", "Add user");
define("USRLAN_61", "Display name");
define("USRLAN_62", "Password");
define("USRLAN_63", "Re-type Password");
define("USRLAN_64", "Email Address");
define("USRLAN_65", "That display name cannot be accepted as valid, please choose a different display name");
define("USRLAN_66", "That display name already exists in the database, please choose a different display name");
define("USRLAN_67", "The two passwords do not match");
define("USRLAN_68", "You left required field(s) blank");
define("USRLAN_69", "That doesn't appear to be a valid email address");
define("USRLAN_70", "User created");
define("USRLAN_71", "Users Front Page");
define("USRLAN_72", "Quick Add User");
define("USRLAN_73", "Prune Users");
define("USRLAN_75", "That login name already exists in the database, please choose a different login name");
define("USRLAN_76", "User Options");
define("USRLAN_77", "Existing Users");
define("USRLAN_78", "User Name");
define("USRLAN_79", "Status");
define("USRLAN_80", "Info");

// define("USRLAN_82", "Are you sure you want to delete this user?");
define("USRLAN_84", "There are");
define("USRLAN_85", "users who haven't activated their account - click below to delete.");
define("USRLAN_86", "User verified");
define("USRLAN_87", "User settings updated");
define("USRLAN_88", "User classes updated");

define("USRLAN_90", "Search/Refresh");
define("USRLAN_91", "Class");
define("USRLAN_92", "Invalid characters in username");

define("USRLAN_93", "Delete unverified users");
define("USRLAN_94", "Delete signups if unverified after this amount of time - leave blank to not use this option <br />This option is ignored if user signups are admin moderated");
define("USRLAN_95", "minutes");


define("USRLAN_112", "Resend Email");
define("USRLAN_113", "Registration details for");
define("USRLAN_114", "Dear");
define("USRLAN_115", "Thanks for your registration.");
define("USRLAN_116", "Please confirm that you wish to resend a confirmation email to:");
define("USRLAN_117", "Click the button below to test the following email:");
define("USRLAN_118", "Test Email");

define("USRLAN_120", "Set Classes");
define("USRLAN_121", "Mailing");
define("USRLAN_122", "Welcome to");
define("USRLAN_123", "Your registration has been received and created.");
define("USRLAN_124", "Your account is currently marked as being inactive, to activate your account please go to the following link");
define("USRLAN_125", "From");

define("USRLAN_126", "Allow users to rate users");
define("USRLAN_127", "Allow comments in user profile");

define("USRLAN_128", "Username");

define("USRLAN_130", "Enable online user tracking");
define("USRLAN_131", "You must enable this option to use online user tracking options, like online.php, forum online info and online menus");
define("USRLAN_132", "Enable");

define("USRLAN_133", "Force user to update settings");
define("USRLAN_134", "Enabling this option will automatically send the user to their user-settings if a required user field is not filled.");

define("USRLAN_135", "No IP address found in user's info; IP not banned");
define("USRLAN_136", "Multiple users found with IP address of {IP}; IP not banned.");
define("USRLAN_137", "Users IP address of {IP} banned.");


define("USRLAN_138", "Unverified users");
define("USRLAN_139", "Your account has been activated.\n\nYou can visit {SITEURL} and log into the site using the login information you provided.");

define("USRLAN_140", "Email Re-sent to");
define("USRLAN_141", "Failed to Re-send email to");
define("USRLAN_142", "with the following activation link");

define("USRLAN_143", "Check For Bounces");
define("USRLAN_144", "Resend Confirmation Email to All");
define("USRLAN_145", "Bounced users");
define("USRLAN_146", "Member information is available to");

define("USRLAN_147", "Email address is already used by a banned user");
define("USRLAN_148", "Email address is banned");

define("USRLAN_149", "Delete checked emails");
define("USRLAN_150", "Delete all emails");
define("USRLAN_151", "Clear bounce, require Activation");
define("USRLAN_152", "Clear bounce and Activate");
define("USRLAN_153", "Delete non-bounce emails");
define("USRLAN_154", "Clear email for checked");
define("USRLAN_155", "Total {TOTAL} emails found. {DELCOUNT} deleted through options.<br />{DELUSER} users marked as 'bounced' (out of {FOUND} emails)");
define("USRLAN_156", "Email address is already in use");

define("LAN_MAINADMIN","Main Admin");
define("LAN_ADMIN","Admin");
define("LAN_NOTVERIFIED","Not Verified");
define("LAN_BANNED","Banned");
define("LAN_BOUNCED","Bounced");

define("DUSRLAN_1", "ID");
define("DUSRLAN_2", "Display Name");
define("DUSRLAN_3", "Username");
define("DUSRLAN_4", "Custom Title");
define("DUSRLAN_5", "Password");
define("DUSRLAN_6", "Photo");
define("DUSRLAN_7", "Email");
define("DUSRLAN_8", "Website");
define("DUSRLAN_9", "ICQ");
define("DUSRLAN_10", "AIM");
define("DUSRLAN_11", "MSN");
define("DUSRLAN_12", "Location");
define("DUSRLAN_13", "Birthday");
define("DUSRLAN_14", "Signature");
define("DUSRLAN_15", "Avatar");
define("DUSRLAN_16", "Timezone");
define("DUSRLAN_17", "Hide Email");
define("DUSRLAN_18", "Join Date");
define("DUSRLAN_19", "Last Visit");
define("DUSRLAN_20", "Current Visit");
define("DUSRLAN_21", "Last Post");
define("DUSRLAN_22", "Chatbox Posts");
define("DUSRLAN_23", "Comments");
define("DUSRLAN_24", "Forum Posts");
define("DUSRLAN_25", "IP");
define("DUSRLAN_26", "Ban");
define("DUSRLAN_27", "Prefs");
define("DUSRLAN_28", "New");
define("DUSRLAN_29", "Viewed");
define("DUSRLAN_30", "Visits");
define("DUSRLAN_31", "Admin");
define("DUSRLAN_32", "Real Name");
define("DUSRLAN_33", "User Class");
define("DUSRLAN_34", "Perms");
define("DUSRLAN_35", "Tracked threads");
define("DUSRLAN_36", "Password Change");
define("DUSRLAN_37", "XUP");

define('USRLAN_219', 'Older than 30 days');     

?>

==> e107_0.7.24_full.tar.gz: e107_languages/English/admin/lan_users.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_users.php $
|     $Revision: 11678 $
|     $Id: lan_users.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("USRLAN_1", "Options Saved.");
define("USRLAN_3", "now listed an Administrator - to set permissions please go to the");
define("USRLAN_4", "Administrator page");
define("USRLAN_5", "You cannot remove admin status of main site admin");
define("USRLAN_6", "has had Administrator status removed.");
define("USRLAN_7", "You cannot ban the main site administrator");
define("USRLAN_8", "User banned.");
define("USRLAN_9", "User unbanned.");
define("USRLAN_10", "User deleted.");
define("USRLAN_11", "Delete cancelled.");
define("USRLAN_12", "You cannot delete the main site administrator.");
define("USRLAN_13", "Please confirm you wish to delete this member");
// define("USRLAN_14", "once deleted the record cannot be retrieved");
// define("USRLAN_15", "Cancel");
define("USRLAN_16", "Confirm Delete");
define("USRLAN_17", "Confirm Delete User");
// define("USRLAN_18", "User activated.");
// define("USRLAN_19", "Search");
// define("USRLAN_20", "Order by");
// define("USRLAN_21", "User ID");
// define("USRLAN_22", "User name");
// define("USRLAN_23", "Visits to site");
// define("USRLAN_24", "Admin status");
// define("USRLAN_25", "Status");
// define("USRLAN_26", "Descending");
// define("USRLAN_27", "Ascending");
// define("USRLAN_28", "Sort");

define("USRLAN_30", "Ban");
// define("USRLAN_31", "Ban -inactivated-");
define("USRLAN_32", "Activate");
define("USRLAN_33", "Unban");
define("USRLAN_34", "Remove admin status");
define("USRLAN_35", "Make admin");
define("USRLAN_36", "Set Class");

// define("USRLAN_37", "Members");
// define("USRLAN_38", "Search returned");
// define("USRLAN_39", "result(s)");
// define("USRLAN_40", "None defined");

define("USRLAN_44", "Allow members to upload an avatar?");

define("USRLAN_47", "Maximum avatar width (in pixels)");
define("USRLAN_48", "default is 120");
define("USRLAN_49", "Maximum avatar height (in pixels)");
define("USRLAN_50", "default is 100");
define("USRLAN_51", "Update Options");
define("USRLAN_52", "Member Options");
define("USRLAN_53", "Allow members to upload a photograph?");
define("USRLAN_54", "Click here to delete all inactivated users");
define("USRLAN_55", "Prune");
define("USRLAN_56", "Deleted");
define("USRLAN_57", "Deleting un-activated members ...");
define("USRLAN_58", "file uploads are disabled in php.ini");
define("USRLAN_59", "Quick add user");
define("USRLAN_60", "Add user");
define("USRLAN_61", "Display name");
define("USRLAN_62", "Password");
define("USRLAN_63", "Re-type Password");
define("USRLAN_64", "Email Address");
define("USRLAN_65", "That display name cannot be accepted as valid, please choose a different display name");
define("USRLAN_66", "That display name already exists in the database, please choose a different display name");
define("USRLAN_67", "The two passwords do not match");
define("USRLAN_68", "You left required field(s) blank");
define("USRLAN_69", "That doesn't appear to be a valid email address");
define("USRLAN_70", "User created");
define("USRLAN_71", "Users Front Page");
define("USRLAN_72", "Quick Add User");
define("USRLAN_73", "Prune Users");
define("USRLAN_75", "That login name already exists in the database, please choose a different login name");
define("USRLAN_76", "User Options");
define("USRLAN_77", "Existing Users");
define("USRLAN_78", "User Name");
define("USRLAN_79", "Status");
define("USRLAN_80", "Info");

// define("USRLAN_82", "Are you sure you want to delete this user?");
define("USRLAN_84", "There are");
define("USRLAN_85", "users who haven't activated their account - click below to delete.");
define("USRLAN_86", "User verified");
define("USRLAN_87", "User settings updated");
define("USRLAN_88", "User classes updated");

define("USRLAN_90", "Search/Refresh");
define("USRLAN_91", "Class");
define("USRLAN_92", "Invalid characters in username");

define("USRLAN_93", "Delete unverified users");
define("USRLAN_94", "Delete signups if unverified after this amount of time - leave blank to not use this option <br />This option is ignored if user signups are admin moderated");
define("USRLAN_95", "minutes");


define("USRLAN_112", "Resend Email");
define("USRLAN_113", "Registration details for");
define("USRLAN_114", "Dear");
define("USRLAN_115", "Thanks for your registration.");
define("USRLAN_116", "Please confirm that you wish to resend a confirmation email to:");
define("USRLAN_117", "Click the button below to test the following email:");
define("USRLAN_118", "Test Email");

define("USRLAN_120", "Set Classes");
define("USRLAN_121", "Mailing");
define("USRLAN_122", "Welcome to");
define("USRLAN_123", "Your registration has been received and created.");
define("USRLAN_124", "Your account is currently marked as being inactive, to activate your account please go to the following link");
define("USRLAN_125", "From");

define("USRLAN_126", "Allow users to rate users");
define("USRLAN_127", "Allow comments in user profile");

define("USRLAN_128", "Username");

define("USRLAN_130", "Enable online user tracking");
define("USRLAN_131", "You must enable this option to use online user tracking options, like online.php, forum online info and online menus");
define("USRLAN_132", "Enable");

define("USRLAN_133", "Force user to update settings");
define("USRLAN_134", "Enabling this option will automatically send the user to their user-settings if a required user field is not filled.");

define("USRLAN_135", "No IP address found in user's info; IP not banned");
define("USRLAN_136", "Multiple users found with IP address of {IP}; IP not banned.");
define("USRLAN_137", "Users IP address of {IP} banned.");


define("USRLAN_138", "Unverified users");
define("USRLAN_139", "Your account has been activated.\n\nYou can visit {SITEURL} and log into the site using the login information you provided.");

define("USRLAN_140", "Email Re-sent to");
define("USRLAN_141", "Failed to Re-send email to");
define("USRLAN_142", "with the following activation link");

define("USRLAN_143", "Check For Bounces");
define("USRLAN_144", "Resend Confirmation Email to All");
define("USRLAN_145", "Bounced users");
define("USRLAN_146", "Member information is available to");

define("USRLAN_147", "Email address is already used by a banned user");
define("USRLAN_148", "Email address is banned");

define("USRLAN_149", "Delete checked emails");
define("USRLAN_150", "Delete all emails");
define("USRLAN_151", "Clear bounce, require Activation");
define("USRLAN_152", "Clear bounce and Activate");
define("USRLAN_153", "Delete non-bounce emails");
define("USRLAN_154", "Clear email for checked");
define("USRLAN_155", "Total {TOTAL} emails found. {DELCOUNT} deleted through options.<br />{DELUSER} users marked as 'bounced' (out of {FOUND} emails)");
define("USRLAN_156", "Email address is already in use");

define("LAN_MAINADMIN","Main Admin");
define("LAN_ADMIN","Admin");
define("LAN_NOTVERIFIED","Not Verified");
define("LAN_BANNED","Banned");
define("LAN_BOUNCED","Bounced");

define("DUSRLAN_1", "ID");
define("DUSRLAN_2", "Display Name");
define("DUSRLAN_3", "Username");
define("DUSRLAN_4", "Custom Title");
define("DUSRLAN_5", "Password");
define("DUSRLAN_6", "Photo");
define("DUSRLAN_7", "Email");
define("DUSRLAN_8", "Website");
define("DUSRLAN_9", "ICQ");
define("DUSRLAN_10", "AIM");
define("DUSRLAN_11", "MSN");
define("DUSRLAN_12", "Location");
define("DUSRLAN_13", "Birthday");
define("DUSRLAN_14", "Signature");
define("DUSRLAN_15", "Avatar");
define("DUSRLAN_16", "Timezone");
define("DUSRLAN_17", "Hide Email");
define("DUSRLAN_18", "Join Date");
define("DUSRLAN_19", "Last Visit");
define("DUSRLAN_20", "Current Visit");
define("DUSRLAN_21", "Last Post");
define("DUSRLAN_22", "Chatbox Posts");
define("DUSRLAN_23", "Comments");
define("DUSRLAN_24", "Forum Posts");
define("DUSRLAN_25", "IP");
define("DUSRLAN_26", "Ban");
define("DUSRLAN_27", "Prefs");
define("DUSRLAN_28", "New");
define("DUSRLAN_29", "Viewed");
define("DUSRLAN_30", "Visits");
define("DUSRLAN_31", "Admin");
define("DUSRLAN_32", "Real Name");
define("DUSRLAN_33", "User Class");
define("DUSRLAN_34", "Perms");
define("DUSRLAN_35", "Tracked threads");
define("DUSRLAN_36", "Password Change");
define("DUSRLAN_37", "XUP");

define('USRLAN_219', 'Older than 30 days');     

?>
